Bahub
=====

Bahub (Backup Hub) is a shell client for the `File Repository` API.
Features total backups automation on your server - the API is storing, versioning and rotating your backups, 
Bahub is optionally encrypting, then sending the data to that storage API.

**Features:**

- Automatically schedule backups
- Encrypt backups with own key
- Custom backup commands that are producing output to capture
- Native MySQL support
- Native PostgreSQL support
- Docker offline backup (container turned off)
- Docker online backup (on live container)

Copyleft
--------

Created by **RiotKit Collective** as part of Wolnościowiec initiative.
Project initially created for three purposes: 

- To store static files uploaded for users (libertarian/anarchist portal)
- To store and serve training video files (video archive)
- To store backups and version those. Limit the disk space and permissions to create a shared space for multiple organizations fighting for human-rights, tenants-rights, working-class rights and animals-rights.
